@@ -5,7 +5,7 @@
     <name>PictureBox</name>
     <message>
         <source>Press to login</source>
-        <translation>Przytrzymaj, aby zalogować się</translation>
+        <translation>Przytrzymaj, aby się zalogować</translation>
     </message>
 </context>
 <context>
@@ -49,6 +49,14 @@
         <source>Select your user and enter password</source>
         <translation>Wybierz konto i wprowadź hasło</translation>
     </message>
+    <message>
+        <source>Enter your username</source>
+        <translation>Wpisz nazwę użytkownika</translation>
+    </message>
+    <message>
+        <source>Enter your password</source>
+        <translation>Wpisz hasło</translation>
+    </message>
     <message>
         <source>Reboot</source>
         <translation>Uruchom ponownie</translation>
@@ -61,6 +69,14 @@
         <source>Shutdown</source>
         <translation>Wyłącz</translation>
     </message>
+    <message>
+        <source>Suspend</source>
+        <translation>Uśpij</translation>
+    </message>
+    <message>
+        <source>Hibernate</source>
+        <translation>Zahibernuj</translation>
+    </message>
     <message>
         <source>User name</source>
         <translation>Nazwa użytkownika</translation>
