@@ -35,7 +35,7 @@ namespace SDDM {
         const QString &name() const;
 
     public slots:
-        void createDisplay(int terminalId = -1);
+        bool createDisplay(int terminalId = -1);
         void removeDisplay(SDDM::Display* display);
 
     private slots:
