@@ -21,7 +21,7 @@
 #ifndef GREETERAPP_H
 #define GREETERAPP_H
 
-#include <QGuiApplication>
+#include <QObject>
 #include <QScreen>
 #include <QQuickView>
 
@@ -38,27 +38,38 @@ namespace SDDM {
     class KeyboardModel;
 
 
-    class GreeterApp : public QGuiApplication
+    class GreeterApp : public QObject
     {
         Q_OBJECT
         Q_DISABLE_COPY(GreeterApp)
     public:
-        explicit GreeterApp(int &argc, char **argv);
+        explicit GreeterApp(QObject *parent = nullptr);
 
-        static GreeterApp *instance() { return self; }
+        bool isTestModeEnabled() const;
+        void setTestModeEnabled(bool value);
+
+        QString socketName() const;
+        void setSocketName(const QString &name);
+
+        QString themePath() const;
+        void setThemePath(const QString &path);
+
+    protected:
+        void customEvent(QEvent *event) override;
 
     private slots:
         void addViewForScreen(QScreen *screen);
         void removeViewForScreen(QQuickView *view);
 
     private:
-        static GreeterApp *self;
+        bool m_testing = false;
+        QString m_socket;
+        QString m_themePath;
 
         QList<QQuickView *> m_views;
         QTranslator *m_theme_translator { nullptr },
                     *m_components_tranlator { nullptr };
 
-        QString m_themePath;
         ThemeMetadata *m_metadata { nullptr };
         ThemeConfig *m_themeConfig { nullptr };
         SessionModel *m_sessionModel { nullptr };
@@ -66,8 +77,15 @@ namespace SDDM {
         GreeterProxy *m_proxy { nullptr };
         KeyboardModel *m_keyboard { nullptr };
 
+        void startup();
         void activatePrimary();
     };
+
+    class StartupEvent : public QEvent
+    {
+    public:
+        StartupEvent();
+    };
 }
 
 
