@@ -30,6 +30,11 @@
 
 #include <pwd.h>
 
+#if defined(Q_OS_FREEBSD)
+#include <sys/types.h>
+#include <login_cap.h>
+#endif
+
 namespace SDDM {
     Backend::Backend(HelperApp* parent)
             : QObject(parent)
@@ -70,6 +75,42 @@ namespace SDDM {
                         .arg(mainConfig.X11.UserAuthFile.get());
                 env.insert(QStringLiteral("XAUTHORITY"), value);
             }
+#if defined(Q_OS_FREEBSD)
+        /* get additional environment variables via setclassenvironment();
+            this needs to be done here instead of in UserSession::setupChildProcess
+            as the environment for execve() is prepared here
+        */
+        login_cap_t *lc;
+
+        if (lc = login_getpwclass(pw)) {
+            // save, clear and later restore SDDM's environment because
+            // setclassenvironment() mangles it
+            QProcessEnvironment savedEnv = QProcessEnvironment::systemEnvironment();
+            QProcessEnvironment::systemEnvironment().clear();
+            QString savedLang = env.value(QStringLiteral("LANG"));
+
+            // setclassenvironment() is the implementation inside setusercontext()
+            // so use lowest-level function there
+            setclassenvironment(lc, pw, 1);     /* path variables */
+            setclassenvironment(lc, pw, 0);     /* non-path variables */
+            login_close(lc);
+            if (lc = login_getuserclass(pw)) {
+                setclassenvironment(lc, pw, 1);
+                setclassenvironment(lc, pw, 0);
+                login_close(lc);
+            }
+
+            // copy all environment variables that are now set
+            env.insert(QProcessEnvironment::systemEnvironment());
+            // for sddm itself, we don't want to set LANG from capabilities.
+            // instead, honour sddm_lang variable from rc script
+            if (qobject_cast<HelperApp*>(parent())->user() == QStringLiteral("sddm"))
+                env.insert(QStringLiteral("LANG"), savedLang);
+            // finally, restore original helper environment
+            QProcessEnvironment::systemEnvironment().clear();
+            QProcessEnvironment::systemEnvironment().insert(savedEnv);
+        }
+#endif
             // TODO: I'm fairly sure this shouldn't be done for PAM sessions, investigate!
             m_app->session()->setProcessEnvironment(env);
         }
