@@ -24,6 +24,7 @@
 #include "SafeDataStream.h"
 
 #include "MessageHandler.h"
+#include "VirtualTerminal.h"
 
 #include <QtCore/QTimer>
 #include <QtCore/QFile>
@@ -35,7 +36,9 @@
 #include <sys/socket.h>
 #include <sys/time.h>
 
+#if defined(Q_OS_LINUX)
 #include <utmp.h>
+#endif
 #include <utmpx.h>
 #include <QByteArray>
 
@@ -105,8 +108,8 @@ namespace SDDM {
             return;
         }
 
-        connect(m_socket, SIGNAL(connected()), this, SLOT(doAuth()));
-        connect(m_session, SIGNAL(finished(int)), this, SLOT(sessionFinished(int)));
+        connect(m_socket, &QLocalSocket::connected, this, &HelperApp::doAuth);
+        connect(m_session, QOverload<int>::of(&QProcess::finished), this, &HelperApp::sessionFinished);
         m_socket->connectToServer(server, QIODevice::ReadWrite | QIODevice::Unbuffered);
     }
 
@@ -148,6 +151,11 @@ namespace SDDM {
 
         if (!m_session->path().isEmpty()) {
             env.insert(m_session->processEnvironment());
+            // Allocate a new VT for the wayland session
+            if(env.value(QStringLiteral("XDG_SESSION_TYPE")) == QLatin1String("wayland")) {
+                int vtNumber = VirtualTerminal::setUpNewVt();
+                env.insert(QStringLiteral("XDG_VTNR"), QString::number(vtNumber));
+            }
             m_session->setProcessEnvironment(env);
 
             if (!m_backend->openSession()) {
@@ -277,18 +285,18 @@ namespace SDDM {
             tty.append(vt);
             QByteArray ttyBa = tty.toLocal8Bit();
             const char* ttyChar = ttyBa.constData();
-            strncpy(entry.ut_line, ttyChar, sizeof(entry.ut_line));
+            strncpy(entry.ut_line, ttyChar, sizeof(entry.ut_line) - 1);
         }
 
         // ut_host: displayName
         QByteArray displayBa = displayName.toLocal8Bit();
         const char* displayChar = displayBa.constData();
-        strncpy(entry.ut_host, displayChar, sizeof(entry.ut_host));
+        strncpy(entry.ut_host, displayChar, sizeof(entry.ut_host) - 1);
 
         // ut_user: user
         QByteArray userBa = user.toLocal8Bit();
         const char* userChar = userBa.constData();
-        strncpy(entry.ut_user, userChar, sizeof(entry.ut_user));
+        strncpy(entry.ut_user, userChar, sizeof(entry.ut_user) -1);
 
         gettimeofday(&tv, NULL);
         entry.ut_tv.tv_sec = tv.tv_sec;
@@ -300,15 +308,21 @@ namespace SDDM {
             qWarning() << "Failed to write utmpx: " << strerror(errno);
         endutxent();
 
+#if !defined(Q_OS_FREEBSD)
         // append to failed login database btmp
         if (!authSuccessful) {
+#if defined(Q_OS_LINUX)
             updwtmpx("/var/log/btmp", &entry);
+#endif
         }
 
         // append to wtmp
         else {
+#if defined(Q_OS_LINUX)
             updwtmpx("/var/log/wtmp", &entry);
+#endif
         }
+#endif
     }
 
     void HelperApp::utmpLogout(const QString &vt, const QString &displayName, qint64 pid) {
@@ -325,13 +339,13 @@ namespace SDDM {
             tty.append(vt);
             QByteArray ttyBa = tty.toLocal8Bit();
             const char* ttyChar = ttyBa.constData();
-            strncpy(entry.ut_line, ttyChar, sizeof(entry.ut_line));
+            strncpy(entry.ut_line, ttyChar, sizeof(entry.ut_line) - 1);
         }
 
         // ut_host: displayName
         QByteArray displayBa = displayName.toLocal8Bit();
         const char* displayChar = displayBa.constData();
-        strncpy(entry.ut_host, displayChar, sizeof(entry.ut_host));
+        strncpy(entry.ut_host, displayChar, sizeof(entry.ut_host) - 1);
 
         gettimeofday(&tv, NULL);
         entry.ut_tv.tv_sec = tv.tv_sec;
@@ -343,8 +357,12 @@ namespace SDDM {
             qWarning() << "Failed to write utmpx: " << strerror(errno);
         endutxent();
 
+#if defined(Q_OS_LINUX)
         // append to wtmp
         updwtmpx("/var/log/wtmp", &entry);
+#elif defined(Q_OS_FREEBSD)
+        pututxline(&entry);
+#endif
     }
 }
 
